
## CATO-CLI - mutation.policy.antiMalwareFileHash.updateSection:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.updateSection) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.updateSection:

`catocli mutation policy antiMalwareFileHash updateSection -h`

`catocli mutation policy antiMalwareFileHash updateSection <json>`

`catocli mutation policy antiMalwareFileHash updateSection "$(cat < mutation.policy.antiMalwareFileHash.updateSection.json)"`

`catocli mutation policy antiMalwareFileHash updateSection '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"policyUpdateSectionInput":{"id":"id","policyUpdateSectionInfoInput":{"name":"string"}}}'`


#### Operation Arguments for mutation.policy.antiMalwareFileHash.updateSection ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`policyUpdateSectionInput` [PolicyUpdateSectionInput] - (required) N/A    
